# piraha-peg Python3
Piraha is a [Parsing Expression Grammar](https://en.wikipedia.org/wiki/Parsing_expression_grammar) library written in Python3

See the top level README for this repo, and the example files.
